==> libtasn1-0.2.3.tar.gz: libtasn1-0.2.3/tests/Test_tree_asn1_tab.c <==

#include "libtasn1.h"

const ASN1_ARRAY_TYPE Test_tree_asn1_tab[]={
  {"TEST_TREE",536875024,0},
  {0,1610612748,0},
  {"iso",1073741825,"1"},
  {"identified-organization",1073741825,"3"},
  {"dod",1073741825,"6"},
  {"internet",1073741825,"1"},
  {"security",1073741825,"5"},
  {"mechanisms",1073741825,"5"},
  {"pkix",1073741825,"7"},
  {"id-mod",1073741825,"0"},
  {"id-pkix1-implicit-88",1,"2"},
  {"SequenceTestTag",1610612741,0},
  {"int1",1610620931,0},
  {0,2056,"2"},
  {"int2",1610620931,0},
  {0,4104,"3"},
  {"str1",1610620930,"PrintableString"},
  {0,4104,"1"},
  {"str2",1073741826,"UniversalString"},
  {"str3",536879106,"UniversalString"},
  {0,2056,"2"},
  {"Sequence1",1610612741,0},
  {"int1",1610915843,0},
  {0,1073741833,"v2"},
  {0,1073745928,"0"},
  {"v1",1073741825,"0"},
  {"v2",1073741825,"1"},
  {"v3",1,"2"},
  {"int2",1073741827,0},
  {"seq",1610612751,0},
  {0,3,0},
  {"id",1073741836,0},
  {"oct",1073741831,0},
  {"any1",541081613,0},
  {"id",1,0},
  {"DHParameter",1610612741,0},
  {"prime",1073741827,0},
  {"base",1073741827,0},
  {"privateValueLength",16387,0},
  {"id-octetTest1",1879048204,0},
  {0,1073741825,"1"},
  {0,1073741825,"2"},
  {0,1073741825,"3"},
  {0,1,"4"},
  {"Sequence_octetTest1",1610612741,0},
  {"int",3,0},
  {"AnyTest2",1610612754,0},
  {"str",1073741831,0},
  {"int",3,0},
  {"id-ic",1879048204,0},
  {0,1073741825,"2"},
  {0,1,"5"},
  {"id-anyTest",1879048204,0},
  {0,1073741825,"id-ic"},
  {0,1073741825,"29"},
  {0,1,"1"},
  {"id-anyTest2",1879048204,0},
  {0,1073741825,"id-ic"},
  {0,1073741825,"29"},
  {0,1,"2"},
  {"anyTest2",1073741827,0},
  {"VisibleString",1610620935,0},
  {0,4360,"26"},
  {"NumericString",1610620935,0},
  {0,4360,"18"},
  {"IA5String",1610620935,0},
  {0,4360,"22"},
  {"TeletexString",1610620935,0},
  {0,4360,"20"},
  {"PrintableString",1610620935,0},
  {0,4360,"19"},
  {"UniversalString",1610620935,0},
  {0,4360,"28"},
  {"BMPString",1610620935,0},
  {0,4360,"30"},
  {"UTF8String",1610620935,0},
  {0,4360,"12"},
  {"Test3",1610612741,0},
  {"a",1073741827,0},
  {"b",536879106,"GeneralString2"},
  {0,2056,"1"},
  {"GeneralString2",1610620955,0},
  {0,2056,"2"},
  {"X520LocalityName",1610612754,0},
  {"teletexString",1073741826,"TeletexString"},
  {"printableString",1073741826,"PrintableString"},
  {"universalString",1073741826,"UniversalString"},
  {"utf8String",1073741826,"UTF8String"},
  {"bmpString",2,"BMPString"},
  {"id-Test",805306380,0},
  {0,1073741825,"1"},
  {0,1073741825,"2"},
  {0,1073741825,"29"},
  {0,1,"2"},
  {0,0,0}
};

==> libtasn1-0.2.18.tar.gz: libtasn1-0.2.18/tests/Test_tree_asn1_tab.c <==

#include "libtasn1.h"

const ASN1_ARRAY_TYPE Test_tree_asn1_tab[]={
  {"TEST_TREE",536875024,0},
  {0,1610612748,0},
  {"iso",1073741825,"1"},
  {"identified-organization",1073741825,"3"},
  {"dod",1073741825,"6"},
  {"internet",1073741825,"1"},
  {"security",1073741825,"5"},
  {"mechanisms",1073741825,"5"},
  {"pkix",1073741825,"7"},
  {"id-mod",1073741825,"0"},
  {"id-pkix1-implicit-88",1,"2"},
  {"OidTest",1610612741,0},
  {"oid3",1610653708,0},
  {0,1073741833,"id-Test"},
  {0,4104,"3"},
  {"oid",1610653708,0},
  {0,1073741833,"id-anyTest2"},
  {0,4104,"1"},
  {"oid2",536911884,0},
  {0,1073741833,"id-anyTest"},
  {0,4104,"2"},
  {"OidAndTimeTest",1610612741,0},
  {"set",1610612751,0},
  {0,3,0},
  {"oid",1073741836,0},
  {"time2",1082130449,0},
  {"bol",1073741828,0},
  {"oct",1073741831,0},
  {"bit",1073758214,0},
  {"bol2",1610645508,0},
  {0,65545,0},
  {"enum",1610907669,0},
  {0,1073741833,"v1"},
  {"v1",1073741825,"1"},
  {"v2",1,"2"},
  {"any",1610637325,0},
  {0,4104,"1"},
  {"gen",1073758235,0},
  {"time1",16777233,0},
  {"SequenceTestTag",1610612741,0},
  {"int1",1610620931,0},
  {0,2056,"2"},
  {"int2",1610620931,0},
  {0,4104,"3"},
  {"str1",1610620930,"PrintableString"},
  {0,4104,"1"},
  {"str2",1073741826,"UniversalString"},
  {"str3",536879106,"UniversalString"},
  {0,2056,"2"},
  {"Sequence1",1610612741,0},
  {"int1",1610915843,0},
  {0,1073741833,"v2"},
  {0,1073745928,"0"},
  {"v1",1073741825,"0"},
  {"v2",1073741825,"1"},
  {"v3",1,"2"},
  {"int2",1073741827,0},
  {"seq",1610612751,0},
  {0,3,0},
  {"id",1073741836,0},
  {"oct",1073741831,0},
  {"any1",541081613,0},
  {"id",1,0},
  {"DHParameter",1610612741,0},
  {"prime",1073741827,0},
  {"base",1073741827,0},
  {"privateValueLength",16387,0},
  {"id-octetTest1",1879048204,0},
  {0,1073741825,"1"},
  {0,1073741825,"2"},
  {0,1073741825,"3"},
  {0,1,"4"},
  {"Sequence_octetTest1",1610612741,0},
  {"int",3,0},
  {"AnyTest2",1610612754,0},
  {"str",1073741831,0},
  {"int",3,0},
  {"id-ic",1879048204,0},
  {0,1073741825,"2"},
  {0,1,"5"},
  {"id-anyTest",1879048204,0},
  {0,1073741825,"id-ic"},
  {0,1073741825,"29"},
  {0,1,"1"},
  {"id-anyTest2",1879048204,0},
  {0,1073741825,"id-ic"},
  {0,1073741825,"29"},
  {0,1,"2"},
  {"anyTest2",1073741827,0},
  {"VisibleString",1610620935,0},
  {0,4360,"26"},
  {"NumericString",1610620935,0},
  {0,4360,"18"},
  {"IA5String",1610620935,0},
  {0,4360,"22"},
  {"TeletexString",1610620935,0},
  {0,4360,"20"},
  {"PrintableString",1610620935,0},
  {0,4360,"19"},
  {"UniversalString",1610620935,0},
  {0,4360,"28"},
  {"BMPString",1610620935,0},
  {0,4360,"30"},
  {"UTF8String",1610620935,0},
  {0,4360,"12"},
  {"Test3",1610612741,0},
  {"a",1073741827,0},
  {"b",536879106,"GeneralString2"},
  {0,2056,"1"},
  {"GeneralString2",1610620955,0},
  {0,2056,"2"},
  {"X520LocalityName",1610612754,0},
  {"teletexString",1073741826,"TeletexString"},
  {"printableString",1073741826,"PrintableString"},
  {"universalString",1073741826,"UniversalString"},
  {"utf8String",1073741826,"UTF8String"},
  {"bmpString",2,"BMPString"},
  {"id-Test",805306380,0},
  {0,1073741825,"1"},
  {0,1073741825,"2"},
  {0,1073741825,"29"},
  {0,1,"2"},
  {0,0,0}
};
